from Plugins.Plugin import PluginDescriptor
from Tools.Directories import pathExists
from enigma import getDesktop
from Screens.Screen import Screen
from Components.ActionMap import ActionMap
from Components.Label import Label
from Components.ScrollLabel import ScrollLabel
from Components.FileList import FileList
from Components.Console import Console
from os import system, mkdir, path, rmdir

def applySkinVars(skin,dict):
	for key in dict.keys():
			try:
					skin = skin.replace('{'+key+'}',dict[key])
			except:
					print(e,"@key=",key)
	return skin

Imagemount = "/tmp/startup_device"
startup_device = ""
kernel_device = ""

def getStartupDevice():
	if not path.isdir(Imagemount):
		mkdir(Imagemount)
	for device in ('/dev/block/by-name/bootoptions', '/dev/mmcblk0p1', '/dev/mmcblk0p2', '/dev/mmcblk0p3', '/dev/mmcblk0p4', '/dev/mmcblk0p5', '/dev/mmcblk0p6', '/dev/mmcblk0p7', '/dev/mmcblk0p8'):
		if path.exists(device):
			Console().ePopen("mount %s %s" % (device, Imagemount))
			if path.isfile(path.join(Imagemount, "STARTUP")):
				print ('[Multiboot] Startupdevice found:', device)
				return device
			Console().ePopen("umount %s" % Imagemount)
	if not path.ismount(Imagemount):
		rmdir(Imagemount)

def readPart():
	try:
		if not path.isdir(Imagemount):
			mkdir(Imagemount)
		Console().ePopen("mount %s %s" % (startup_device, Imagemount))
		STARTUP = open("/tmp/startup_device/STARTUP", 'r').readline().split(' ')
		STARTUP = STARTUP[1].split('.')
		kerneldevice = STARTUP[1]
		if kerneldevice == "kernel1" or kerneldevice == "kernel_1":
			kerneldevice = "- Partition 1"
		elif kerneldevice == "kernel2" or kerneldevice == "kernel_2":
			kerneldevice = "- Partition 2"
		elif kerneldevice == "kernel3" or kerneldevice == "kernel_3":
			kerneldevice = "- Partition 3"
		elif kerneldevice == "kernel4" or kerneldevice == "kernel_4":
			kerneldevice = "- Partition 4"
		Console().ePopen("umount %s" % Imagemount)
		if not path.ismount(Imagemount):
			rmdir(Imagemount)
	except:
		pass
	return kerneldevice

class STB_Startup(Screen):
	skin = """
		<screen position="center,center" size="{screen.size}" title="{title}" >
			<widget name="filelist" position="{list.pos}" size="{list.size}" font="Regular;18" scrollbarMode="showOnDemand" />
			<widget name="textpage" position="{list.pos}" size="{list.size}" font="Regular;26" />
		</screen>"""

	def __init__(self, session):

		startup_device = getStartupDevice()
		kernel_device = readPart()

		current_w = getDesktop(0).size().width()
		current_h = getDesktop(0).size().height()

		if current_w == 1280:
				size_w = 720
				size_h = 376
		else:
				size_w = 520
				size_h = 376

		font = "Regular;18"
		pos_w = (current_w - size_w)/2
		pos_h = (current_h - size_h)/2
		list_w = size_w - 20
		list_pos = (size_w - list_w)/2

		if not path.isdir(Imagemount):
			mkdir(Imagemount)
		Console().ePopen("mount %s %s" % (startup_device, Imagemount))

		self.dict = {
				'title': "STB-Startup v1.05 %s"%(kernel_device),
				'font': font,
				'list.size': "%i,306"%(list_w),
				'list.pos': "%i,50"%(list_pos),
				'screen.size': "%i,%i"%(size_w,size_h)
				}
		self.skin = applySkinVars(STB_Startup.skin,self.dict)

		Screen.__init__(self, session)

		self["currentfolder"] = Label("")
		self["textpage"] =  ScrollLabel()
		self["textpage"].hide()

		self.LIST_TEXT = 1
		self.LIST_FILE = 2

		self.focus = self.LIST_FILE

		self["actions"] = ActionMap(["OkCancelActions", "DirectionActions"],
		{
			"ok": self.KeyOk,
			"cancel": self.Exit,
			"right": self.rightDown,
			"left": self.leftUp,
			"up": self.up,
			"down": self.down
		}, -1)

		self.SearchPattern = "^.*"

		self.filelist = []

		self.currDir = Imagemount

		if not pathExists(self.currDir):
			self.currDir = "/"

		self["currentfolder"].setText(self.currDir)

		self.filelist = FileList(self.currDir, showDirectories = False, showFiles = True, showMountpoints = False, isTop = True, matchingPattern = self.SearchPattern)

		self["filelist"] = self.filelist
		self["filelist"].show()

	def KeyOk(self):
		self.filename = self.filelist.getCurrentDirectory() + "/" + self.filelist.getFilename()
		self.filename_dest = self.filelist.getCurrentDirectory() + "/STARTUP"
		if self.filename is not None:
			cmdline = 'cp -f "%s" "%s"' % (self.filename, self.filename_dest)
			system(cmdline)

		self.text="Umgeschaltet auf <" + self.filelist.getFilename() + ">"
		self["filelist"].hide()
		self["textpage"].setText(str(self.text))
		self["textpage"].show()
		self.focus = self.LIST_TEXT

	def up(self):
		if self.focus is self.LIST_TEXT:
			self["textpage"].pageUp()
		else:
			self["filelist"].up()

	def down(self):
		if self.focus is self.LIST_TEXT:
			self["textpage"].pageDown()
		else:
			self["filelist"].down()

	def leftUp(self):
		self["filelist"].pageUp()

	def rightDown(self):
		self["filelist"].pageDown()

	def Exit(self):
		Console().ePopen("umount %s" % Imagemount)
		if not path.ismount(Imagemount):
			rmdir(Imagemount)
		self.close()

def main(session, **kwargs):
	session.open(STB_Startup)

def Plugins(**kwargs):
	return [
		PluginDescriptor(name = "STB-Startup", description = "STB-Startup", where = PluginDescriptor.WHERE_PLUGINMENU, fnc=main, icon = "stb-startup.png"),
		PluginDescriptor(name = "STB-Startup", description = "STB-Startup", where = PluginDescriptor.WHERE_EXTENSIONSMENU, fnc=main, icon = "stb-startup.png")]
